/**
 * Единый объект для хранения всех блоков и манипуляциями с ними
 */
var Scene = {
	
	/* Зарегистрированные блоки (iblock) в которых будет обработка */
	blocks: {},
	
	/* Текущий блок */
	current: null,
	
	/* Предыдущий блок */
	prev: null,
	
	/* сбрасываем текущее состоянии для перехода между сценами */
	reset: function () {
		this.blocks = {};
		this.current = null;
	},
	
	/* Регистрируем блок */
	addScene: function (name, iblock) {
		this.blocks[name] = iblock;
		this.blocks[name].init();
	},
	
	setCurrentBlock: function (name, params) {
		
		for (var i in this.blocks) {
			this.blocks[i].onBlur();
		}
		
		this.prev = this.current ? this.current.name : 'index';
		this.current = this.blocks[name];
		this.current.name = name;
		
		this.current 
			? this.current.onFocus(params)
			: false;

	},
	
	backBlock: function (params) {
		this.setCurrentBlock(this.prev, params);
	},
	
	/* Нажатие на клавишу выход */
	onPressExit: function () { 
		this.current
			? this.current.onPressExit()
			: false;
	},
	
	/* Нажатие на клавишу вверх */
	onPressUp: function () { 
		this.current
			? this.current.onPressUp()
			: false;
	},
	
	/* Нажатие на клавишу вниз */
	onPressDown: function () {
		this.current
			? this.current.onPressDown()
			: false;
	},
	
	/* Нажатие на клавишу влево */
	onPressLeft: function () {
		this.current
			? this.current.onPressLeft()
			: false;
	},
	
	/* Нажатие на клавишу вправо */
	onPressRight: function () {
		this.current
			? this.current.onPressRight()
			: false;
	},
	
	/* Нажатие на клавишу enter */
	onPressEnter: function () {
		this.current
			? this.current.onPressEnter()
			: false;
	},
	
	/* Нажатие на клавишу A */
	onPressA: function() { 
		this.current
			? this.current.onPressA()
			: false;
	},
	
	/* Нажатие на клавишу B */
	onPressB: function() {
		this.current
			? this.current.onPressB()
			: false;
	},
	
	/* Нажатие на клавишу C */
	onPressC: function() {
		this.current
			? this.current.onPressC()
			: false;
	},
	
	/* Нажатие на клавишу D */
	onPressD: function() {
		this.current
			? this.current.onPressD()
			: false;
	},
	
	/* Нажатие на клавишу tools */
	onPressTools: function() {
		this.current
			? this.current.onPressTools()
			: false;
	},
	
	/* Нажатие на клавишу Вернуться */
	onPressReturn: function() {
		this.current
			? this.current.onPressReturn()
			: false;
	},
	
	/* Нажатие на цифры */
	onPress1: function() {
		this.current
			? this.current.onPress1()
			: false;
	},
	
	onPress2: function() {
		this.current
			? this.current.onPress2()
			: false;
	},
	
	onPress3: function() {
		this.current
			? this.current.onPress3()
			: false;
	},
	
	onPress4: function() {
		this.current
			? this.current.onPress4()
			: false;
	},
	
	onPress5: function() {
		this.current
			? this.current.onPress5()
			: false;
	},
	
	onPress6: function() {
		this.current
			? this.current.onPress6()
			: false;
	},
	
	onPress7: function() {
		this.current
			? this.current.onPress7()
			: false;
	},
	
	onPress8: function() {
		this.current
			? this.current.onPress8()
			: false;
	},
	
	onPress9: function() {
		this.current
			? this.current.onPress9()
			: false;
	},
	
	onPress0: function() {
		this.current
			? this.current.onPress0()
			: false;
	},
	
	/* пауза */
	onPressPause: function() {
		this.current
			? this.current.onPressPause()
			: false;
	},
	
	/* пауза */
	onPressPlay: function() {
		this.current
			? this.current.onPressPlay()
			: false;
	},
	
	/* стоп */
	onPressStop: function() {
		this.current
			? this.current.onPressStop()
			: false;
	},
	
	/* перепотка вправо */
	onPressFF: function() {
		this.current
			? this.current.onPressFF()
			: false;
	},
	
	/* перепотка влево */
	onPressRF: function() {
		this.current
			? this.current.onPressRF()
			: false;
	},
	
	/* формат изображения*/
	onPressAspect: function() {
		this.current
			? this.current.onPressAspect()
			: false;
	},
	
	/* 3D */
	onPress3D: function() {
		this.current
			? this.current.onPress3D()
			: false;
	},
	
	/* Info */
	onPressInfo: function() {
		this.current
			? this.current.onPressInfo()
			: false;
	}
	
}

/**
 * Общий класс для блоков
 * var leftBlock = $.extend({}, iBlock, {});
 *
 */
var iBlock = {
	onFocus: function (params) { },
	onBlur: function () { },
	onPressUp: function() { },
	onPressDown: function() { },
	onPressLeft: function() { },
	onPressRight: function() { },
	onPressEnter: function() { },
	onPressA: function() { },
	onPressB: function() { },
	onPressC: function() { },
	onPressD: function() { },
	onPressTools: function() { },
	onPressReturn: function() { },
	onPress1: function() { },
	onPress2: function() { },
	onPress3: function() { },
	onPress4: function() { },
	onPress5: function() { },
	onPress6: function() { },
	onPress7: function() { },
	onPress8: function() { },
	onPress9: function() { },
	onPress0: function() { },
	onPressPause: function() { },
	onPressPlay: function() { },
	onPressStop: function() { },
	onPressFF: function() { },
	onPressRF: function() { },
	onPressAspect: function() { },
	onPress3D: function() { },
	onPressInfo: function() { },
	onPressExit: function() {
		widgetAPI.sendExitEvent();
		widgetAPI.blockNavigation(event);
	},
	init: function() { },
	
	/**
	 * перейти на другой блок 
	 * @param string blockName			Имя блока
	 * @param string activeSelector		CSS селектор элемента который станет активным после перехода (гапример :last)
	 */
	jumpTo: function (blockName, params) {
		Scene.setCurrentBlock(blockName, params);
	},
	
	back:function (params) {
		Scene.backBlock(params);
	}

}
