/**
 * Страница проигрывания видео
 */
var VideoScene = $.extend({}, iBlock, {

	/**
	 * Обертки
	 */
	_wrappers: {
		main: null,				// обертка сцены
		bottom_panel: null,		// нижняя панелька с кнопками
		time_panel: null		// панель текущего времени видео времени
	},
	
	/**
	 * @var object Таймеры
	 */
	_timers: {
		seek: null,			// таймер для перемотки видео (нажали на кнопку и мотаем таймер без перемотки самого видео пока кнопку не отпустим)
		hidePanel: null,	// прячем нанель через n секунд
		onTime: null		// таймер для отображения времени
	},

	/**
	 * Ссылка на титульную сцену
	 * @var object IndexScene
	 */
	_indexScene: IndexScene,
	
	_lockSeek: false,
	
	_3DMode: 0,
	
	onFocus: function (filmData) {
		
		var _this = this;

		$('#body').tmp(this._templates.index(), {mac: this._macAddr});
		this._wrappers = {
			main: $('#player'),
			bottom_panel: $('#bottom_images'),
			time_panel: $('#seeking')
		}
		
		this._currentFilm = filmData;
		this._startPlay();
		this._set3DMode(0);

	},
	
	onBlur: function () {
		for (i in this._timers) {
			clearInterval(this._timers[i]);
			clearTimeout(this._timers[i]);
		}
		this._hidePreloader();
	},
	
	onPressReturn: function (skipStopAuto) {

		if (!skipStopAuto) {
			IndexScene.stopAuto();
		}

		this._destroyPlayer();
		this._hidePreloader();		
		this._wrappers.main.remove();
		
    	this.back();

	},
	
	onPress1: function () { 
		this._seekVideo(AdapterPlayer.getDuration() * 0.1);
	},
	onPress2: function () {
		this._seekVideo(AdapterPlayer.getDuration() * 0.2);
	},
	onPress3: function () {
		this._seekVideo(AdapterPlayer.getDuration() * 0.3);
	},
	onPress4: function () {
		this._seekVideo(AdapterPlayer.getDuration() * 0.4);
	},
	onPress5: function () {
		this._seekVideo(AdapterPlayer.getDuration() * 0.5);
	},
	onPress6: function () {
		this._seekVideo(AdapterPlayer.getDuration() * 0.6);
	},
	onPress7: function () {
		this._seekVideo(AdapterPlayer.getDuration() * 0.7);
	},
	onPress8: function () {
		this._seekVideo(AdapterPlayer.getDuration() * 0.8);
	},
	onPress9: function () {
		this._seekVideo(AdapterPlayer.getDuration() * 0.9);
	},
	onPressPause: function () {
		this._showBottomPanel();
		AdapterPlayer.pause();
	},
	onPressPlay: function () {
		AdapterPlayer.play();
	},
	onPressFF: function () {
		this._seekVideo(AdapterPlayer.getCurrentTime(), 30);
	},
	onPressRF: function () {
		this._seekVideo(AdapterPlayer.getCurrentTime(), -30);
	},
	onPressExit: function () {
		this.onPressReturn();
	},
	onPress3D: function () {
		
		this._3DMode = this._3DMode == 2 ? 0 : (this._3DMode + 1);
		this._set3DMode(this._3DMode);
		
	},
	
	onPressInfo: function () {
		this._showBottomPanel();
		this._hideBottomPanel();
	},
	
	onPressRight: function () {
		this.onPressReturn(true);
	},
	
	/**
	 * Переключаем режим 3D
	 *
	 * @param int mode		Режим 3D - 0 нету, 1 - горизонтальная пара, 2 - вертикальная пара
	 */
	_set3DMode: function (mode) {
		var screen = document.getElementById('pluginObjectScreen');
		screen.Set3DEffectMode(mode);
	},
	
	/**
	 * Проигрываем видео
	 */
	_startPlay: function () {

		var _this = this;
		
		_this._showPreloader();
		
		_log('adapter: ' + (this._currentFilm.content_type.indexOf('f4m') != -1 ? 'AdapterUppod' : 'AdapterJWPlayer'));
		_log('url: ' + this._currentFilm.url);
		
		AdapterPlayer.setAdapter(this._currentFilm.content_type.indexOf('f4m') != -1 ? AdapterUppod : AdapterJWPlayer);
		AdapterPlayer.init(this._currentFilm.url, this._currentFilm.time_shift, this._currentFilm.content_type, this._currentFilm.id);
		
		AdapterPlayer.onEnd(function () {
			$('#debug').append('end');
			_this.onPressReturn();
			_this._indexScene.completeFilm();
		});
		
		AdapterPlayer.onPlay(function () {
			$('#debug').append('play');
			_this._hidePreloader();
			_this._showBottomPanel();
			_this._hideBottomPanel();
			clearTimeout(_this._timers.file404);
		});
		
		AdapterPlayer.onError(function () {
			Dialog.alert('Выбранный фильм не доступен для просмотра.', 'Ошибка', function () {
				_this.onPressReturn();
			});
		});
		
		AdapterPlayer.onInit(function () {
			
			clearInterval(_this._timers.onTime);
			_this._timers.onTime = setInterval(function () {

				if (_this._lockSeek) return;
				
				var position = Math.ceil(AdapterPlayer.getCurrentTime()),
					duration = parseInt(AdapterPlayer.getDuration());
	
				if (duration > 0 && Math.round(position) % 15 == 0) {
					_this._indexScene.saveTimeshift(position);
				}
				
				if (position > 0) {
					_this._showTimer();
				}
	
			}, 500);
			
		});
		
		AdapterPlayer.onBuffer(function () {
			_this._showPreloader();
		});
		
		AdapterPlayer.onBufferEnd(function () {
			_this._hidePreloader();
		});
		
	},

	/**
	 * Показываем троббер
	 */
	_showPreloader: function (status) {
		throbberImage('show');
	},
	
	/**
	 * Прячем троббер
	 */
	_hidePreloader: function () {
		throbberImage('hide');
	},
	
	/**
	 * Показываем панель с кнопками снизу
	 */
	_showBottomPanel: function () {
		this._wrappers.bottom_panel.show();
		clearTimeout(this._timers.hidePanel);
	},
	
	
	/**
	 * Прячем панель с кнопками снизу
	 */
	_hideBottomPanel: function () {

		var _this = this;
		
		this._timers.hidePanel = setTimeout(function () {
			_this._wrappers.bottom_panel.fadeOut();
		}, 10000);

	},
	
	/**
	 * Отображаем текущее время по видео
	 * @param time время для отображения (optional)
	 */
	_showTimer: function (time) {
		
		this._wrappers.time_panel
			.removeClass('paused')
			.removeClass('forward')
		
		if (AdapterPlayer.isPaused()) {
			this._wrappers.time_panel.addClass('paused');
		}

		if (time) {
			this._wrappers.time_panel.addClass('forward');
		}
		
		var _current = time || AdapterPlayer.getCurrentTime(),
			_diration = parseInt(AdapterPlayer.getDuration()),
			_str = formatTime(_current) + ' / ' + formatTime(_diration) + ' (' + Math.round(_current / _diration * 100) + '%)';
		
		if (_diration > 0) {
			this._wrappers.time_panel.html(_str);
		}
		else {
			this._wrappers.time_panel.html(formatTime(_current));
			$('.seek', this._wrappers.bottom_panel).hide();
		}

	},
	
	
	/**
	 * Перемотка видео
	 */
	_seekVideo: function(toTime, plusedTime) {
		
		var _this = this;
		
		this.onPressPause();
		
		clearTimeout(this._timers.seek);
		
		this._lockSeek = parseInt(this._lockSeek ? this._lockSeek : toTime);
		this._lockSeek += plusedTime ? plusedTime : 0;
		
		if (this._lockSeek <= 0) this._lockSeek = 0;
		if (this._lockSeek >= AdapterPlayer.getDuration() - 30) this._lockSeek = AdapterPlayer.getDuration() - 30;

		this._showTimer(this._lockSeek);

		this._timers.seek = setTimeout(function () {
			AdapterPlayer.seekTo(parseInt(_this._lockSeek) + '.01')
			_this._lockSeek = false;
		}, 2000);
		
	},
	
	
	/**
	 * Удаление обекта плеера и всех его таймеров
	 */
	_destroyPlayer: function () {
		
		this._3DMode = 0;
		clearTimeout(this._timers.seek);
		AdapterPlayer.destroy();

	},
	
	_templates: {
		
		index: function () {
			
			return '<div id="player"></div>\
					<div id="bottom_images" class="player_bottom">\
						<div id="seeking"></div>\
						<span id="p_0_9" class="seek">Перемотка на % от фильма</span>\
						<span id="fr_ff" class="seek">Перемотка Назад / Вперёд</span>\
						<span id="pause">Пауза</span>\
						<span id="play">Пуск</span>\
						<span id="return">Назад</span>\
					</div>\
				';
			
		}
		
	}
	
});